==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libkom++/membership.h <==
// Handle a membership in a conference.
//
// $Id: membership.h,v 1.10 1995/11/18 22:49:48 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef KOMXX_MEMBERSHIP_H
#define KOMXX_MEMBERSHIP_H

#include <DLList.h>
#include <time.h>

#include "misc.h"
#include "kom-types.h"

class prot_a_LyStr;


//
// Information about a person's membership in a conference
//
class Membership {
 public:
    Membership();
    Membership(const Membership&);
    Membership(Pers_no pno, prot_a_LyStr &prot_a_str);
    Membership(int errno);
    ~Membership();
    const Membership &operator =(const Membership &);

    bool   valid() const;
    int    errno() const;

    Conf_no        conf_no()                        const;
    int            placement()                      const;
    unsigned char  priority()                       const;
    struct tm      last_time_read()                 const;
    
    bool           is_read(Local_text_no)           const;
    Local_text_no  last_text_read()                 const;
    long	   num_read_after_last_text_read()  const;

 private:
    struct Membership_internal {
	Membership_internal();
	Membership_internal(Pers_no pno, prot_a_LyStr &str);
	Membership_internal(const Membership_internal &);
	const Membership_internal & operator =(const Membership_internal &);

	int      refcount;
	Pers_no  this_pers_no;
	int      kom_errno;

	Conf_no		m_conf_no;
	unsigned char	m_priority; // Interrupt priority 
	struct tm	m_last_time_read;   // Updated every time a text in 
	                                    // this conf. is marked as read.
	Local_text_no	m_last_text_read;   // All texts before and
                                            // inclusive this are read.
	DLList<Local_text_no> read_texts;   // Texts after last_text_read.
				            // Sorted in ascending order. 
    };

    Membership_internal * memb_int;
};
#endif

==> kom%2B%2B-0.7.tar.gz: kom++-0.7/libkom++/membership.h <==
// Handle a membership in a conference.
//
// $Id: membership.h,v 1.12 1996/07/11 09:28:40 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef KOMXX_MEMBERSHIP_H
#define KOMXX_MEMBERSHIP_H

#include <DLList.h>
#include <time.h>

#include "misc.h"
#include "kom-types.h"
#include "error-codes.h"

class prot_a_LyStr;


//
// Information about a person's membership in a conference
//
class Membership {
 public:
    Membership();
    Membership(const Membership&);
    Membership(Pers_no pno, prot_a_LyStr &prot_a_str);
    Membership(Kom_err errno);
    ~Membership();
    const Membership &operator =(const Membership &);

    bool   initialized() const;
    Kom_err errno() const;

    Conf_no        conf_no()                        const;
    int            placement()                      const;
    unsigned char  priority()                       const;
    struct tm      last_time_read()                 const;

    // Retrieve information about unread texts.
    bool           is_read(Local_text_no)           const;
    Local_text_no  last_text_read()                 const;
    long	   num_read_after_last_text_read()  const;

    // Update the information about unread texts.
    void mark_as_read(Local_text_no);
    void set_last_text_read(Local_text_no);

    // Force the cache to refetch this information from the server.
    void invalidate();

    // Set the internal membership to a specified state.  This will
    // affect all Membership objects that refer to the same
    // reference-counted internal structure.
    void set(Membership);
 private:
    struct Membership_internal {
	Membership_internal();
	Membership_internal(Pers_no pno, prot_a_LyStr &str);
	Membership_internal(const Membership_internal &);
	const Membership_internal & operator =(const Membership_internal &);

	int      refcount;
	Pers_no  this_pers_no;
	Kom_err  kom_errno;

	Conf_no		m_conf_no;
	unsigned char	m_priority; // Interrupt priority 
	struct tm	m_last_time_read;   // Updated every time a text in 
	                                    // this conf. is marked as read.
	Local_text_no	m_last_text_read;   // All texts before and
                                            // inclusive this are read.
	DLList<Local_text_no> read_texts;   // Texts after last_text_read.
				            // Sorted in ascending order. 
    };

    Membership_internal * memb_int;
};
#endif
